# Spawn 

This is the spawn executable. 
There are currently two capabilities provided by this program.
1. Create an FMU given an EnergyPlus idf file
2. Compile a given Modelica model

There is currently no capability to simulate an FMU, however that will be added in the future.
Until then PyFMI or similar may be used to simulate FMUs generated by this program.

## Nightly Builds

End user installer packages for the latest development builds are available at the following locations.

* [Linux](https://spawn.s3.amazonaws.com/latest/Spawn-latest-Linux.tar.gz).
* [Mac](https://spawn.s3.amazonaws.com/latest/Spawn-latest-Darwin.tar.gz).
* [Windows](https://spawn.s3.amazonaws.com/latest/Spawn-latest-win64.zip).

## Compiling from source

* Install EnergyPlus dependencies according to https://github.com/NREL/EnergyPlus/wiki/BuildingEnergyPlus

* Ensure that your system has been setup the same as it would be for compiling EnergyPlus, but with one addition,

* Install clang development libraries. One Linux this would be...
```shell
apt-get install libllvm8 llvm-8-dev clang-8 libclang-8-dev
```

```shell
pip install conan
```

* If neccessary add variables to locate llvm and clang. (not required for apt-get installed linux packages)
```shell
export LLVM_DIR=/path/to/llvm/
export Clang_DIR=/path/to/clang/
```

* Install Graal from https://github.com/graalvm/graalvm-ce-builds/releases. Spawn requires the java8 "ce" package, which is the community open source version.
Extract the graal tarball and include the bin directory in the system path. After installing graal the "native-image" utility must be installed separately according to the directions here https://www.graalvm.org/docs/reference-manual/native-image/#install-native-image.

```shell
gu install native-image
```

* Then follow the normal cmake build process.

```shell
git clone --recurse-submodules https://github.com/NREL/spawn.git
cd spawn
mkdir build
cd build
cmake ../
make -j
```

## Example Usage

* Create a fmu. The .spawn file defines the resources that will be compiled into an EnergyPlus based FMU. 
The most important items are epw and idf files.


```shell
./spawn --export examples/RefBldgSmallOfficeNew2004_Chicago/RefBldgSmallOfficeNew2004_Chicago.spawn

```

The resulting fmu will be located in examples/RefBldgSmallOfficeNew2004_Chicago/MyBuilding.fmu,
and may be tested with pyfmi or other fmu simulation tools.

* Compile a Modelica model to FMU format. Models contained with the Modelica Buildings Library and
the Modelica Standard Library are included and available to the compiler by default

```shell
./spawn --compile Buildings.Examples.Tutorial.Boiler.System1

```

The output of the above command is expected as the following.

```shell
$ ./spawn -c Buildings.Examples.Tutorial.Boiler.System1
Parse Model
Instantiate Model
Flatten Model
Generate C Code
Compile C Code
Model Compiled
```

Resulting in the FMU directory, which includes a fully linked shared library, 
`Buildings_Examples_Tutorial_Boiler_System1.so` corresponding to the compiled version
of the given Modelica model


```shell
$ find Buildings_Examples_Tutorial_Boiler_System1/
Buildings_Examples_Tutorial_Boiler_System1/
Buildings_Examples_Tutorial_Boiler_System1/sources
Buildings_Examples_Tutorial_Boiler_System1/sources/Buildings_Examples_Tutorial_Boiler_System1_init_independent.c
Buildings_Examples_Tutorial_Boiler_System1/sources/Buildings_Examples_Tutorial_Boiler_System1_base.c
Buildings_Examples_Tutorial_Boiler_System1/sources/Buildings_Examples_Tutorial_Boiler_System1_funcs.c
Buildings_Examples_Tutorial_Boiler_System1/sources/Buildings_Examples_Tutorial_Boiler_System1_base.h
Buildings_Examples_Tutorial_Boiler_System1/sources/Buildings_Examples_Tutorial_Boiler_System1.c
Buildings_Examples_Tutorial_Boiler_System1/sources/Buildings_Examples_Tutorial_Boiler_System1_equ_init.c
Buildings_Examples_Tutorial_Boiler_System1/sources/Buildings_Examples_Tutorial_Boiler_System1_init_dependent.c
Buildings_Examples_Tutorial_Boiler_System1/sources/Buildings_Examples_Tutorial_Boiler_System1_equ.c
Buildings_Examples_Tutorial_Boiler_System1/resources
Buildings_Examples_Tutorial_Boiler_System1/binaries
Buildings_Examples_Tutorial_Boiler_System1/binaries/Buildings_Examples_Tutorial_Boiler_System1.so
Buildings_Examples_Tutorial_Boiler_System1/out.log
Buildings_Examples_Tutorial_Boiler_System1/modelDescription.xml
```

* List available options

```shell
$ ./spawn -h
Spawn of EnergyPlus
Usage: ./spawn [OPTIONS]

Options:
  -h,--help                   Print this help message and exit
  -c,--compile TEXT           Compile Modelica model to FMU format
  -e,--export TEXT=spawn.json Export a standalone EnergyPlus based FMU
  --no-zip Needs: --export    Skip compressing the contents of the fmu into a zip archive
  -v,--version                Print version info and exit
```

## Data Exchange Variables

The variables exposed through the FMU are documented here:
https://lbl-srg.github.io/soep/softwareArchitecture.html#coupling-of-envelope-model,
however check the modelDescription.xml contained in the generated fmu because
some variables may not be implemented yet.

